@@ -54,7 +54,7 @@ class TwoCaptcha():
         self.exceptions = SolverExceptions
 
     def normal(self, file, **kwargs):
-        '''Wrapper for solving normal captcha (image).
+        '''Wrapper for solving a normal captcha (image).
 
         Parameters
         __________
@@ -879,8 +879,10 @@ class TwoCaptcha():
 
         Parameters
         _________
+        method : str
+            The name of the method must be found in the documentation https://2captcha.com/2captcha-api
         kwargs: dict
-
+            All captcha params
         Returns
 
         """
@@ -1026,6 +1028,7 @@ class TwoCaptcha():
             return params, files
 
         if not '.' in hint and len(hint) > 50:
+            params.update({'imginstructions': hint})
             return params, files
 
         if not os.path.exists(hint):
